@@ -28,10 +28,10 @@ def create_strong_authentication(user_id, beneficiary_id=None):
 
 
 @task
-def sync_resource(resource_klass, resource_id):
+def sync_status(resource_klass, resource_id):
     from leetchi.base import DoesNotExist
 
-    logger = sync_resource.get_logger()
+    logger = sync_status.get_logger()
 
     try:
 
@@ -55,6 +55,25 @@ def sync_resource(resource_klass, resource_id):
         logger.exception(e)
 
 
+@task
+def sync_resource(resource_klass, resource_id):
+    from leetchi.base import DoesNotExist
+
+    logger = sync_resource.get_logger()
+
+    try:
+
+        resource = resource_klass.objects.get(pk=resource_id)
+        resource.sync()
+
+        resource_name = resource_klass.__name__
+
+        logger.info(u'[%s]: syncing %d, from leetchi resource %d' %
+                    (resource_name, resource.pk, resource.resource_id))
+    except (APIError, DecodeError, DoesNotExist), e:
+        logger.exception(e)
+
+
 @task
 def update_user(user_id, **kwargs):
     from .compat import User
